@@ -6,7 +6,7 @@
 #define MAEMO5PAPERBACKGROUNDDIALOG_H
 
 #include <QDialog>
-#include "paperbackground.h"
+#include "ppbackground.h"
 
 namespace Ui {
     class Maemo5PaperBackgroundDialog;
@@ -20,24 +20,30 @@ public:
     explicit Maemo5PaperBackgroundDialog(QWidget *parent = 0);
     ~Maemo5PaperBackgroundDialog();
 
-    void setColor(QColor val);
-    QColor color();
+    void setDefaultBackground(PPBackground val);
 
     /// The selected background
-    PaperBackground selectBackground();
+    PPBackground selectedBackground();
+
+    void refresh();
 
 protected:
     void changeEvent(QEvent *e);
+    bool eventFilter(QObject *, QEvent *);
 
 private:
+    void loadTemplate();
     Ui::Maemo5PaperBackgroundDialog *ui;
-
-    /// Last selected color
-    QColor m_color;
+    PPBackground background;
 
 private slots:
-    void on_colorButton_clicked();
+    void on_filesButton_clicked();
+    void on_clearButton_clicked();
+    void on_databaseButton_clicked();
     void on_confirmButton_clicked();
+
+    void selectColor();
+
 };
 
 #endif // MAEMO5PAPERBACKGROUNDDIALOG_H
