@@ -6,6 +6,7 @@
 #include "pageentity.h"
 #include "snapshotentity.h"
 #include "tables.h"
+#include "sketchxmlpaper.h"
 
 Page::Page(QObject *parent) :
     QObject(parent)
@@ -51,7 +52,7 @@ bool StandardPage::load(int pageId) {
     return res;
 }
 
-bool StandardPage::save(Paper *paper,QRect source) {
+bool StandardPage::save(SketchPaper *paper,QRect source) {
 
     // Save page
     QDomDocument doc = toXml();
@@ -59,18 +60,17 @@ bool StandardPage::save(Paper *paper,QRect source) {
     bool res = m_entity.save(Storage::instance());
 
     // Snapshot
-    QPixmap snapshot(200,168);
+    QPixmap snapshot(source.size());
 //    snapshot.fill(QColor(255,255,255,255));
     QGraphicsScene *scene = paper->scene();
     QPainter painter(&snapshot);
-    QRectF target(0,0,200,168);
+    QRectF target(0,0,source.width(),source.height());
 
-    if (scene) {
+    if (scene)
         scene->render(&painter,target,source,Qt::KeepAspectRatio);
-    } else {
-        paper->snapshot(&painter,target);
-    }
+
     painter.end();
+    snapshot = snapshot.scaled(QSize(200,168),Qt::KeepAspectRatio,Qt::SmoothTransformation);
 
     QBuffer buffer;
     buffer.open(QIODevice::ReadWrite);
@@ -88,7 +88,7 @@ bool StandardPage::save(Paper *paper,QRect source) {
 void StandardPage::clear(){
     m_entity.reset();
 
-    Paper* paper = content();
+    SketchPaper* paper = content();
     paper->clear();
     paper->setRect(defaultRect);
 }
@@ -121,9 +121,15 @@ bool StandardPage::setFromXml(QDomDocument &doc){
 
     QDomElement paperElem = contentElem.firstChildElement("paper");
 
-    Paper *paper = content();
+    SketchPaper *paper = content();
     paper->clear();
+
+    /*
     paper->setFromElement(paperElem);
+    */
+    SketchXmlPaper xml;
+    xml.read(paperElem);
+    xml.write(paper);
 
     return true;
 }
@@ -140,14 +146,17 @@ QDomDocument StandardPage::toXml() {
     QDomElement contentElem = doc.createElement("content");
     page.appendChild(contentElem);
 
-    Paper* paper = content();
-    QDomElement paperElem = paper->createElement(doc);
-    contentElem.appendChild(paperElem);
+    SketchPaper* paper = content();
+    SketchXmlPaper xml;
+    xml.read(paper);
+    xml.write(contentElem);
+//    QDomElement paperElem = paper->createElement(doc);
+//    contentElem.appendChild(paperElem);
 
     return doc;
 }
 
-Paper* StandardPage::content(){
+SketchPaper* StandardPage::content(){
     if (!m_content) {
         m_content = new SketchPaper();
         if (m_entity.id() > 0 ) {
@@ -155,7 +164,10 @@ Paper* StandardPage::content(){
             doc.setContent(m_entity.content());
             QDomElement contentNode = doc.firstChildElement("content");
             QDomElement paperNode = contentNode.firstChildElement("paper");
-            m_content->setFromElement(paperNode);
+//            m_content->setFromElement(paperNode);
+            SketchXmlPaper xml;
+            xml.read(paperNode);
+            xml.write(m_content);
         }
     }
     return m_content;
