@@ -5,7 +5,7 @@
 #include <QDomDocument>
 #include <QObject>
 #include <QGraphicsView>
-#include "paper.h"
+#include "sketchpaper.h"
 #include "storage.h"
 #include "pageentity.h"
 
@@ -38,12 +38,12 @@ public:
 
     void newPage(int bookId);
     bool load(int pageId);
-    bool save(Paper *paper,QRect source);
+    bool save(SketchPaper *paper,QRect source);
     void clear();
     void remove();
 
     /// The content paper
-    Paper* content();
+    SketchPaper* content();
     PageEntity *entity();
 
     virtual bool setFromXml(QDomDocument &doc);
@@ -53,7 +53,7 @@ private:
     PageEntity m_entity;
 
     /// The content paper
-    QPointer<Paper> m_content;
+    QPointer<SketchPaper> m_content;
 
     QRect defaultRect;
 
