@@ -2,7 +2,7 @@
 #define TABLES_H
 
 #include <QString>
-#include "paper.h"
+#include "sketchpaper.h"
 #include "storage.h"
 
 /// Database Entity
