@@ -3,12 +3,16 @@
 #include <QMessageBox>
 #include <QFileDialog>
 #include <QDesktopServices>
+#include <QKeyEvent>
 #include "pageeditorwindow.h"
 #include "ui_pageeditorwindow.h"
 #include "maemo5paperbackgrounddialog.h"
 
 #ifdef Q_WS_MAEMO_5
 #include <QMaemo5InformationBox>
+#include <QtGui/QX11Info>
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
 #endif
 
 PageEditorWindow::PageEditorWindow(QWidget *parent) :
@@ -17,16 +21,19 @@ PageEditorWindow::PageEditorWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
+    zooming = false;
+
     ui->toolBar->setContextMenuPolicy(Qt::PreventContextMenu);
     QList<QAction*> actions = ui->drawpad->actions();
     ui->toolBar->addActions(actions);
 
-    ui->toolBar->addSeparator();
+//    ui->toolBar->addSeparator();
     actions = ui->drawpad->directionActions();
     ui->toolBar->addActions(actions);
 
+    ui->toolBar->addAction(ui->actionFullScreen);
 
-    m_backgroundColor = Qt::white;
+    m_background.setColor(Qt::white);
 
     m_page = new StandardPage(this);
     open(-1);
@@ -34,6 +41,33 @@ PageEditorWindow::PageEditorWindow(QWidget *parent) :
     menuBar()->addAction(ui->actionBackground);
     menuBar()->addAction(ui->actionDelete);
     menuBar()->addAction(ui->actionExport);
+    setMenuVisible(false);
+
+    connect(ui->drawpad,SIGNAL(modeChanged()),
+            this,SLOT(onModeChanged()));
+
+#ifdef Q_WS_MAEMO_5
+    if (!winId()) {
+        qWarning("Can't grab keys unless we have a window id");
+    }
+
+    unsigned long val = 1;
+    Atom atom = XInternAtom(QX11Info::display(), "_HILDON_ZOOM_KEY_ATOM", False);
+    if (!atom) {
+        qWarning("Unable to obtain _HILDON_ZOOM_KEY_ATOM. This example will only work "
+                 "on a Maemo 5 device!");
+        return;
+    }
+
+    XChangeProperty (QX11Info::display(),
+            winId(),
+            atom,
+            XA_INTEGER,
+            32,
+            PropModeReplace,
+            reinterpret_cast<unsigned char *>(&val),
+            1);
+#endif
 }
 
 PageEditorWindow::~PageEditorWindow()
@@ -67,6 +101,21 @@ void PageEditorWindow::showEvent(QShowEvent *event){
     setMenuVisible(true);
 }
 
+void PageEditorWindow::keyPressEvent(QKeyEvent* event){
+    qreal step = 0.2;
+    switch (event->key()) {
+        case Qt::Key_F7:
+            zoom( 1 + step);
+            break;
+
+        case Qt::Key_F8:
+            zoom(1 - step);
+            break;
+    }
+    QWidget::keyPressEvent(event);
+
+}
+
 void PageEditorWindow::setMenuVisible(bool val){
     ui->actionBackground->setVisible(val);
     ui->actionDelete->setVisible(val);
@@ -87,9 +136,10 @@ bool PageEditorWindow::open(int pageId) {
     bool res = m_page->load(pageId);
     Q_ASSERT(res);
 
-    Paper* paper = m_page->content();
+    SketchPaper* paper = m_page->content();
     ui->drawpad->setPaper(paper);
     setCenter();
+    zoomNormal();
 
     return true;
 }
@@ -98,13 +148,12 @@ void PageEditorWindow::newPage(int bookId){
     clear();
     m_page->newPage(bookId);
 
-    Paper* paper = m_page->content();
+    SketchPaper* paper = m_page->content();
 
-    PaperBackground bg;
-    bg.setColor(m_backgroundColor);
-    paper->setBackground(bg);
+    paper->setBackground(m_background);
     ui->drawpad->setPaper(paper);
     setCenter();
+    zoomNormal();
 }
 
 void PageEditorWindow::clear(){
@@ -126,12 +175,12 @@ Drawpad* PageEditorWindow::drawpad(){
     return ui->drawpad;
 }
 
-void PageEditorWindow::setBackgroundColor(QColor val){
-    m_backgroundColor = val;
+void PageEditorWindow::setDefaultBackground(PPBackground val){
+    m_background = val;
 }
 
-QColor PageEditorWindow::backgroundColor(){
-    return m_backgroundColor;
+PPBackground PageEditorWindow::lastSelectedBackground(){
+    return m_background;
 }
 
 void PageEditorWindow::on_actionDelete_triggered()
@@ -168,11 +217,8 @@ void PageEditorWindow::on_actionExport_triggered()
                    .arg(time.second(),2,10,QChar('0'))
                    .arg(QDir::homePath() + QLatin1String("/MyDocs"));
 
-    qDebug() << filename;
-
-
     QString path = QFileDialog::getSaveFileName(this,
-                                             tr("Export to file"),
+                                             tr("Export PNG image"),
                                              filename
                                              );
     if (!path.isNull()) {
@@ -198,17 +244,46 @@ void PageEditorWindow::setCenter() {
     ui->drawpad->view()->centerOn(rect.center());
 }
 
+void PageEditorWindow::zoom(qreal factor){
+    zooming = true;
+
+    ui->drawpad->view()->scale(factor,factor);
+    ui->drawpad->setMode(Drawpad::FreeMoveMode);
+}
+
+void PageEditorWindow::zoomNormal(){
+    ui->drawpad->view()->resetMatrix();
+    zooming = false;
+}
+
 void PageEditorWindow::on_actionBackground_triggered()
 {
     Maemo5PaperBackgroundDialog dialog;
 
-    PaperBackground bg = ui->drawpad->paper()->background();
+    PPBackground bg = ui->drawpad->paper()->background();
 
-    dialog.setColor(bg.color());
+    dialog.setDefaultBackground(bg);
     if (dialog.exec() == QDialog::Accepted ) {
-        bg = dialog.selectBackground();
-        m_backgroundColor = bg.color();
-        ui->drawpad->paper()->setBackground(bg);
+        m_background = dialog.selectedBackground();
+        ui->drawpad->paper()->setBackground(m_background);
         ui->drawpad->refresh();
     }
 }
+
+void PageEditorWindow::on_actionFullScreen_triggered()
+{
+    if (isFullScreen()){
+        showNormal();
+    } else {
+        showFullScreen();
+    }
+}
+
+void PageEditorWindow::onModeChanged(){
+    if (zooming) {
+        Drawpad::Mode mode = ui->drawpad->mode();
+        if (mode != Drawpad::FreeMoveMode) {
+            zoomNormal();
+        }
+    }
+}
