@@ -6,6 +6,7 @@
 #include "pageentity.h"
 #include "drawpad.h"
 #include "page.h"
+#include "ppbackground.h"
 
 namespace Ui {
     class PageEditorWindow;
@@ -29,8 +30,8 @@ public:
 
     Drawpad* drawpad();
 
-    void setBackgroundColor(QColor val);
-    QColor backgroundColor();
+    void setDefaultBackground(PPBackground val);
+    PPBackground lastSelectedBackground();
 
 signals:
     void saved(int pageId);
@@ -40,16 +41,19 @@ protected:
     void changeEvent(QEvent *e);
     virtual void closeEvent ( QCloseEvent * event );
     virtual void showEvent(QShowEvent *event);
+    virtual void keyPressEvent(QKeyEvent* event);
 
 private:
     void setMenuVisible(bool val);
     void setCenter();
+    void zoom(qreal factor);
+    void zoomNormal();
 
     Ui::PageEditorWindow *ui;
     StandardPage *m_page;
 
     /// The last selected background color
-    QColor m_backgroundColor;
+    PPBackground m_background;
 
     /// The expected viewport size of QGraphicsView object
     /**
@@ -57,10 +61,15 @@ private:
      */
     QSize viewportSize;
 
+    /// Truth if the draw is zoomed
+    bool zooming;
+
 private slots:
+    void on_actionFullScreen_triggered();
     void on_actionBackground_triggered();
     void on_actionExport_triggered();
     void on_actionDelete_triggered();
+    void onModeChanged();
 };
 
 #endif // PAGEEDITORWINDOW_H
