@@ -1,3 +1,7 @@
+/**
+  @author Ben Lau <xbenlau@gmail.com>
+ */
+
 #ifndef MAEMO5COLORSVPICKER_H
 #define MAEMO5COLORSVPICKER_H
 
