@@ -4,7 +4,9 @@
 #include "mainwindow.h"
 //#include "storage.h"
 //#include "tables.h"
-#include "paperbackground.h"
+#include "pppaperbackground.h"
+#include "ppxmlpaper.h"
+#include "sketchxmlpaper.h"
 
 int main(int argc, char *argv[])
 {
@@ -41,8 +43,9 @@ int main(int argc, char *argv[])
         doc.setContent(data);
 
         QDomElement elem = doc.firstChildElement("paper");
-
-        drawpad->paper()->setFromElement(elem);
+        SketchXmlPaper xml;
+        xml.read(elem);
+        xml.write(drawpad->paper());
         file.close();
     }
 
