@@ -37,7 +37,7 @@ void MainWindow::on_actionBackground_triggered()
 {
     Maemo5PaperBackgroundDialog dialog;
 
-    PaperBackground bg = ui->drawpad->paper()->background();
+    PPPaperBackground bg = ui->drawpad->paper()->background();
 
     dialog.setColor(bg.color());
     if (dialog.exec() == QDialog::Accepted ) {
