@@ -3,7 +3,7 @@
 
 #include <QMainWindow>
 #include "drawpad.h"
-#include "pagemodel.h"
+//#include "pagemodel.h"
 
 namespace Ui {
     class MainWindow;
@@ -24,6 +24,9 @@ protected:
 
 private:
     Ui::MainWindow *ui;
+
+private slots:
+    void on_actionBackground_triggered();
 };
 
 #endif // MAINWINDOW_H
