@@ -1,8 +1,7 @@
 #ifndef BASICUNITTESTS_H
 #define BASICUNITTESTS_H
 
-#include "paper.h"
-#include "graphicsstroke.h"
+#include "ppgraphicsstroke.h"
 #include "storage.h"
 
 class BasicUnitTests : public QObject
@@ -14,9 +13,18 @@ public:
     ~BasicUnitTests();
 
 private slots:
-    /// Test the save & load of GraphicsStroke class
     void stroke_save_load();
 
+    void paper_id();
+
+    void paper_save_load();
+
+    void paperXml_read_write();
+
+
+
+    void graphicsStrokeSnapshot();
+
 };
 
 class StorageUnitTests : public QObject {
